{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Домашнее задание 5\n",
    "**Выполнил: Ким Адамейко, группа мАДБМ16**"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 263,
   "metadata": {},
   "outputs": [],
   "source": [
    "import numpy as np\n",
    "from scipy import optimize\n",
    "import matplotlib.pyplot as plt\n",
    "import seaborn as sns\n",
    "sns.set(color_codes=True)\n",
    "\n",
    "import pubchempy as pcp\n",
    "import py3Dmol\n",
    "\n",
    "from rdkit import Chem\n",
    "from rdkit.Chem import AllChem\n",
    "from rdkit.Chem.Draw import IPythonConsole \n",
    "from __future__ import print_function, division\n",
    "\n",
    "from IPython.display import display,Image, Markdown\n",
    "\n",
    "import os\n",
    "curdir = os.getcwd()\n",
    "! export PATH=${PATH}:/{curdir}\n",
    "\n",
    "def show_compound_3d(smiles, view, grid=(0, 0)):\n",
    "    m2d = Chem.MolFromSmiles(smiles)\n",
    "    m3d = Chem.AddHs(m2d)\n",
    "    Chem.AllChem.EmbedMolecule(m3d)\n",
    "    AllChem.MMFFOptimizeMolecule(m3d,maxIters=500,nonBondedThresh=200 )\n",
    "    mb = Chem.MolToMolBlock(m3d)\n",
    "    view.addModel(mb,'sdf', viewer=grid)\n",
    "    view.setStyle({'model':0},{'stick': {}}, viewer=grid)\n",
    "    view.zoomTo(viewer=grid)\n",
    "    return view"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Будем работать с этаном:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 264,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/html": [
       "<div id=\"3dmolviewer_151450511068\"  style=\"position: relative; width: 300px; height: 300px\">\n",
       "<script>\n",
       "if(typeof $3Dmolpromise === 'undefined') $3Dmolpromise = $.when($.getScript('https://3dmol.csb.pitt.edu/build/3Dmol.js'))\n",
       "var viewer_151450511068 = null;\n",
       "$3Dmolpromise.done(function() {\n",
       "viewer_151450511068 = $3Dmol.createViewer($(\"#3dmolviewer_151450511068\"),{backgroundColor:\"white\"});\n",
       "\tviewer_151450511068.addModel(\"\\n     RDKit          3D\\n\\n  8  7  0  0  0  0  0  0  0  0999 V2000\\n   -0.7520    0.0087   -0.0775 C   0  0  0  0  0  0  0  0  0  0  0  0\\n    0.7520   -0.0087    0.0775 C   0  0  0  0  0  0  0  0  0  0  0  0\\n   -1.2066   -0.8076    0.4918 H   0  0  0  0  0  0  0  0  0  0  0  0\\n   -1.1650    0.9542    0.2863 H   0  0  0  0  0  0  0  0  0  0  0  0\\n   -1.0314   -0.1074   -1.1290 H   0  0  0  0  0  0  0  0  0  0  0  0\\n    1.2065    0.8076   -0.4918 H   0  0  0  0  0  0  0  0  0  0  0  0\\n    1.0314    0.1074    1.1290 H   0  0  0  0  0  0  0  0  0  0  0  0\\n    1.1650   -0.9542   -0.2863 H   0  0  0  0  0  0  0  0  0  0  0  0\\n  1  2  1  0\\n  1  3  1  0\\n  1  4  1  0\\n  1  5  1  0\\n  2  6  1  0\\n  2  7  1  0\\n  2  8  1  0\\nM  END\\n\",\"sdf\");\n",
       "\tviewer_151450511068.setStyle({\"model\": 0},{\"stick\": {}});\n",
       "\tviewer_151450511068.zoomTo();\n",
       "viewer_151450511068.render();\n",
       "});\n",
       "</script>"
      ],
      "text/plain": [
       "<py3Dmol.view at 0x7f526a60af10>"
      ]
     },
     "execution_count": 264,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "view = py3Dmol.view(width=300, height=300)\n",
    "show_compound_3d('CC', view)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Часть 1. Зависимость энергии молекулы от длины связи C−C"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Загрузим оптимизированную структуру этана в виде z-matrix :"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {},
   "outputs": [],
   "source": [
    "inp_init = '''!HF RHF 6-31G\n",
    "* int 0 1\n",
    "C 0 0 0 0 0 0 \n",
    "C 1 0 0 1.52986 0 0 \n",
    "H 1 2 0 1.08439 111.200 0\n",
    "H 1 2 3 1.08439 111.200 120\n",
    "H 1 2 3 1.08439 111.200 -120\n",
    "H 2 1 3 1.08439 111.200 180\n",
    "H 2 1 6 1.08439 111.200 120\n",
    "H 2 1 6 1.08439 111.200 -120\n",
    "*\n",
    "'''"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Цель: рассчитать 20 разных длин связи с шагом 0.02 Å для расчёта энергии в ORCA с разными значениями по длине одной из связей ($\\text{C-C}$). Сделаем на основе данной нам матрицы генератор подобных ей:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 30,
   "metadata": {},
   "outputs": [],
   "source": [
    "def gen_zmatrix(**kwargs):\n",
    "    return '''!HF RHF 6-31G\n",
    "    * int 0 1\n",
    "    C 0 0 0 0 0 0 \n",
    "    C 1 0 0 {blength} 0 0 \n",
    "    H 1 2 0 1.08439 {hcc_angle} 0\n",
    "    H 1 2 3 1.08439 {hcc_angle} 120\n",
    "    H 1 2 3 1.08439 {hcc_angle} -120\n",
    "    H 2 1 3 1.08439 {hcc_angle} {tor1}\n",
    "    H 2 1 5 1.08439 {hcc_angle} {tor2}\n",
    "    H 2 1 5 1.08439 {hcc_angle} {tor3}\n",
    "    *\n",
    "    '''.format(**kwargs)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 132,
   "metadata": {},
   "outputs": [],
   "source": [
    "bl_step = 0.02\n",
    "bl0 = 1.52986\n",
    "tor = 180\n",
    "params1 = {'hcc_angle': 111.200, 'tor1': tor, 'tor2': tor-60, 'tor3': tor+60}\n",
    "blengths = np.linspace(bl0 - bl_step*10, bl0 + bl_step*10, 21)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 133,
   "metadata": {},
   "outputs": [],
   "source": [
    "dir1 = './task1/'\n",
    "! mkdir -p {dir1}\n",
    "energy_values1 = []\n",
    "for bl in blengths:\n",
    "    z = gen_zmatrix(blength = bl, **params1)\n",
    "    ! echo '{z}' > {dir1}{bl}.zm\n",
    "    ! orca {dir1}{bl}.zm > {dir1}{bl}.out 2>{dir1}{bl}.err\n",
    "    res = ! grep 'FINAL SINGLE POINT ENERGY' {dir1}{bl}.out\n",
    "    energy_values1.append(float(res[0].split(' ')[-1]))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Изобразим полученные точки на графике, чтобы \"прикинуть\" начальные значения коэффициентов (т.к. оптимизируем численно итерационно):"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 162,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZoAAAD4CAYAAADVTSCGAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJgAAAABJRU5ErkJggg==\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a0584d0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plt.plot(blengths, energy_values1, \".\")\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Подготовим функцию для построения приближённой модели и вывода информации о ней и графика"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 153,
   "metadata": {},
   "outputs": [],
   "source": [
    "# Параметры: координаты точек, модель, начальные параметры модели\n",
    "def fit_and_plot(xs, ys, fitfunc, init_coef):\n",
    "    \n",
    "    # Минимизируем функцию ошибки\n",
    "    errfunc = lambda coef, x, y: fitfunc(coef, x) - y          \n",
    "    coef, _ = optimize.leastsq(errfunc, init_coef[:], args=(xs, ys))\n",
    "    plt.plot(xs, ys, \".\", xs, fitfunc(coef, xs), \"-\")\n",
    "    plt.show()\n",
    "    print('Mean Square Error = %.3g' % np.square(ys - fitfunc(coef, xs)).mean())\n",
    "    return coef.tolist()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 154,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZoAAAD4CAYAAADVTSCGAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n+v8B2itR2tl47UoAAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a554710>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Mean Square Error = 2.13e-06\n"
     ]
    },
    {
     "data": {
      "text/markdown": [
       "Fitted function: $f(x) = -79.082 + 0.640(x-1.557)^2$"
      ],
      "text/plain": [
       "<IPython.core.display.Markdown object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "coef1 = fit_and_plot(blengths, energy_values1, lambda c, x: c[0]*(x-c[1])**2 + c[2], [1, 1, -79]) \n",
    "display(Markdown(r\"Fitted function: $f(x) = {2:.3f} + {0:.3f}(x-{1:.3f})^2$\".format(*coef1)))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "В статье [1] находим формулу (1)\n",
    "$$E_{\\text{pair}} = \\sum\\limits_\\text{bonds} k_r (r-r_{eq})^2 \n",
    "+ \\sum\\limits_\\text{angles} k_\\theta (\\theta - \\theta_{eq})^2 \n",
    "+ \\sum\\limits_\\text{dihedrals} \\dfrac{v_n}{2}\\left(1 + \\cos (n \\varphi - \\gamma)\\right) \n",
    "+ \\sum\\limits_{i<j}\\left(\n",
    "    \\dfrac{A_{ij}}{R_{ij}^{12}} \n",
    "    - \\dfrac{B_{ij}}{R_{ij}^6}\n",
    "    +\\dfrac{q_i\\,q_j}{\\varepsilon\\,R_{ij}}\\right),$$ \n",
    "\n",
    "где выражения с нижним индексом $_{eq}$ соответствуют параметрам структуры в равновесном состоянии, $k_r,\\ k_\\theta, v_n$ - искомые константы взаимодействия; $n, \\gamma - $ кратность и фазовый угол торсионных углов. Параметры $A, B, q$ характеризуют потенциалы нековалентных взаимодействий. \n",
    "    \n",
    "В нашем случае моделировалось только изменение длины связи, поэтому все суммы кроме первой полагаем равными нулю.   Тогда $E = K_r (r-r_{eq})^2$, откуда $K_r = \\dfrac{E}{(r-r_{eq})^2}$. Т.е. константа ковалентного взаимодействия, согласно нашей модели, равна $0.64 \\dfrac{\\text{Ha}}{Å^2}$, поскольку ORCA выдаёт значение энергии в атомных единицах энергии Хартри. \n",
    "\n",
    "Энергия Хартри равна абсолютному значению электрической потенциальной энергии атома водорода в основном состоянии [2]. При этом $1\\ \\text{Ha} =\t627.509\\ \\text{ккал/моль}$. Можно перевести энергию в Ккал/моль:\n",
    "\n",
    "$E = 0.64 * 627.509 = 401.605\\ \\dfrac{\\text{ккал}}{\\text{моль}\\cdot Å^2}$\n",
    "\n",
    "В статье при этом для длины связи $\\text{C-C}$ использовалась линейная регрессия с двойными логарифмическими координатами (см. рис. 2 в [1]), в результате которой с коэффициентом детерминации $R^2 = 0.987$ получена следующая модель: \n",
    "\n",
    "$$\\log k_r = -4.9575 \\log r + 7.8187,$$\n",
    "\n",
    "Подставим значения для равновесного состояния $(r = 1.52986):$"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 118,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "302.13950564613629"
      ]
     },
     "execution_count": 118,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "np.exp(-4.9575 * np.log(bl0) + 7.8187)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Итак, в статье на основе методов молекулярной динамики, получена константа $302.1\\ \\dfrac{\\text{ккал}}{\\text{моль}\\cdot Å^2}, $ расчёты же, выполненные в ORCA методами квантовой химии, дали результат $401.6\\ \\dfrac{\\text{ккал}}{\\text{моль}\\cdot Å^2}.$ Константы получились одного порядка, хотя и довольно сильно отличающиеся."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Часть 2. Зависимость энергии молекулы от валентного угла HCС"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 127,
   "metadata": {},
   "outputs": [],
   "source": [
    "hcc_step = 0.2\n",
    "hcc0 = 111.2\n",
    "tor = 180\n",
    "params2 = {'blength': 1.52986, 'tor1': tor, 'tor2': tor-60, 'tor3': tor+60}\n",
    "hcc_angles = np.linspace(hcc0 - hcc_step*10, hcc0 + hcc_step*10, 21)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 168,
   "metadata": {},
   "outputs": [],
   "source": [
    "dir2 = './task2/'\n",
    "! mkdir -p {dir2}\n",
    "energy_values2 = []\n",
    "for hcc_angle in hcc_angles:\n",
    "    z = gen_zmatrix(hcc_angle = hcc_angle, **params2)\n",
    "    ! echo '{z}' > {dir2}{bl}.zm\n",
    "    ! orca {dir2}{bl}.zm > {dir2}{bl}.out 2>{dir2}{bl}.err\n",
    "    res = ! grep 'FINAL SINGLE POINT ENERGY' {dir2}{bl}.out\n",
    "    energy_values2.append(float(res[0].split(' ')[-1]))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 169,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZUAAAD4CAYAAAAkRnsLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nERER0/w/HI8OSDU5hzcAAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a004850>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plt.plot(hcc_angles, energy_values2, \".\")\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 170,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAZUAAAD4CAYAAAAkRnsLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAADl0RVh0U29mdHdhcmUAbWF0cGxvdGxpYiB2ZXJzaW9uIDIuMS4xLCBo\ndHRwOi8vbWF0cGxvdGxpYi5vcmcvAOZPmwAAIABJREFUeJzt3XlclXX+///Hdc4BATmCHDiAoKC4\n4K6pKaO2uGaIYuRE2YJLNFnNYJPzKfk1Tn1+M6NO34mmmpL8pOU4fQtTcC2RaRG0lMwFyg1RlFVW\nkcXDcn3/sE7xAQ3kyMXyut9u3YTrnOs6z+sKeJ73da5FUVVVRQghhLABndYBhBBCdB5SKkIIIWxG\nSkUIIYTNSKkIIYSwGSkVIYQQNmPQOoDWamvrKCmp1DpGIz17OkmuFpBcLSO5WkZyNebhYWxyepcf\nqRgMeq0jNElytYzkahnJ1TKSq/m6fKkIIYSwHSkVIYQQNiOlIoQQwmakVIQQQtiMlIoQQgibkVIR\nQghhM1IqN6naUktGThnVllqtowghRLvR5U9+vBnVllpWfribkroC3GuG8MfHxuFgL5tSCCFkpHIT\nsgsrKDWcw67PSS6pGWQXVmgdSQgh2gUplZvg496dntVDUOt1dPM/iZtr+zurVQghtCClchMc7A38\nacGdTDJPRjVcJfFiktaRhBCiXZBSuUkO9gbmD5uJp5MHX17cT1b5Ra0jCSGE5qRUWsFOZ+DXA0NR\nUfm/J7dSr9ZrHUkIITQlpdJKgW4DGOs5ivOXL5CSc1DrOEIIoSkpFRu4r/9sHPQObMvYTbnlitZx\nhBBCM1IqNuDSrQch/WZSWVvF1jM7tY4jhBCakVKxkck+E+jt3Iuv877hdMlZreMIIYQmpFRsRK/T\n88Cg+1BQ+PDUVurq67SOJIQQba5V1xaJiooiMzMTgPLycoxGIwkJCVgsFlauXElaWhqKohAdHc34\n8eMbzV9aWsqyZcvIzs7Gx8eHmJgYXFxcWLduHdu3bwegrq6OjIwMDhw4gKurK++99x5xcXGoqsr8\n+fOJiIi44bLaUl+XPkzsdTvJOV/znwv7mO53V5u+vhBCaK1VI5WYmBgSEhJISEhgxowZTJ8+HYC4\nuDgAtm/fzvr161m9ejX19Y0Pt42NjSUoKIg9e/YQFBREbGwsAEuWLLEu99lnn2XcuHG4urpy6tQp\n4uLiiIuLIyEhgc8//5xz587dcFltbU7ALJzturMrM5GS6lJNMgghhFZssvtLVVV2797N7NmzAThz\n5gwTJkwAwGQyYTQaSUtLazRfUlISoaGhAISGhrJ3795Gz9m5c6d1uRkZGYwcORJHR0cMBgPjxo0j\nMTGx2ctqC93tnJjXPxhLfQ1xp7dpkkEIIbRik1JJTU3FZDLh7+8PQGBgIElJSdTW1nLhwgXS09PJ\nzc1tNF9RURFmsxkAs9lMcXFxg8erqqrYt28fM2bMAGDgwIGkpqZSUlJCVVUVX375JXl5ec1aVlsa\n7zWGAJe+HL2URlrh95rlEEKItvaLn6lERERQWFjYaHpUVBTTpk0DYMeOHdbRBEBYWBgZGRmEhYXR\nq1cvRo8ejV7f8osufvbZZ9x22224uroCEBAQwJIlS1i0aBFOTk4MGjToppb7v3l4GFu9jP/tyQkL\n+K89f+HjjG1MHDAKe4N9u8hlC5KrZSRXy0iulmlvuX6xVDZs2HDDx2tra0lMTGTLli0/LdRgYMWK\nFdbvw8PDraOYnzOZTBQUFGA2mykoKMDNza3B4zt37iQ4OLjBtPnz5zN//nwA/v73v+Pp6dmsZd3I\npUvlzX5ucznSg7t7T2Zv1hf865tthPSb2aL5PTyMtyRXa0mulpFcLSO5WkbLXNcrs1bv/tq/fz/9\n+vXDy8vLOq2qqorKykoAUlJS0Ov19O/fv9G8U6ZMIT4+HoD4+HimTp1qfay8vJxDhw41mAbXdnMB\n5OTksGfPHusI6UbL0sos/2n07ObK3vOfk19RoHUcIYS45VpdKrt27Wo0migqKmLevHnMmjWLd955\nhzVr1lgfi46O5vjx4wBERkaSkpLCjBkzSElJITIy0vq8xMREJk6ciJOTU4NlP/PMM9x777385je/\nYeXKldbDhm+0LK04GLpx/8A51Kp1fHgqHlVVtY4khBC3lKLKX7pbOnxUVZW3jq0nvegEC4c+xFjP\nUc2aT4bbLSO5WkZytYzkavq1myJn1N9iiqLw64FzsdMZ+Pj0dqpqq7SOJIQQt4yUShtwdzQx028q\nly3l7Di7R+s4Qghxy0iptJFpfndidnLni4v7uVCerXUcIYS4JaRU2oidzsADA+fJXSKFEJ2alEob\nCnQbwBjzSM5dziLh+y+ottRqHUkIIWxKSqWNBfvNgnoDiRf38tK/kqVYhBCdipRKG7tSrsdyYQCK\noYZi42GyCyu0jiSEEDYjpdLGfNy741EbSF25KwZTHsXKea0jCSGEzUiptDEHewN/fGwci0c8gEEx\nsCUjgcqaSq1jCSGETUipaMDB3sC4vgHc23caly3lfHx6h9aRhBDCJqRUNDStz530NvrwVV4q6UUn\ntY4jhBCtJqWiIb1Oz8OB89EpOj448TFVtdVaRxJCiFaRUtGYr7EXM/3upuRqKQkZu7WOI4QQrSKl\n0g7M9J+Kd3dP9mUf4FRJhtZxhBDipkmptAN2OgMPD56PgsKmE5ux1Fm0jiSEEDdFSqWd8O/Rh6l9\n7qCwqojtZz/VOo4QQtwUKZV2JLjvDMyO7nx2IZlThWe1jiOEEC0mpdKO2OvtWDB4Pioqbx3aSE29\nXBdMCNGxSKm0M/1d+3Kn76/IvpzHJ5l7tY4jhBAtIqXSDs3pNwsPJzf2ZH0uN/QSQnQoUirtkIOh\nG0+Me5h6tZ5/fR9HXX2d1pGEEKJZpFTaqRFeg/mV9zguXskhMetzreMIIUSzSKm0Y/P6z8bFvge7\nM/eSW5GvdRwhhPhFhtbMHBUVRWZmJgDl5eUYjUYSEhKwWCysXLmStLQ0FEUhOjqa8ePHN5q/tLSU\nZcuWkZ2djY+PDzExMbi4uLBu3Tq2b98OQF1dHRkZGRw4cABXV1fee+894uLiUFWV+fPnExERAcDr\nr7/ORx99hJubGwDPPvssd955Z2tWT3NOdo6ED5rH2uPv8a/v4/j9mKXoFHkfIIRov1pVKjExMdav\nV61ahbOzMwBxcXEAbN++naKiIh5//HE2b96MTtfwD2JsbCxBQUFERkYSGxtLbGwsy5cvZ8mSJSxZ\nsgSA//znP2zYsAFXV1dOnTpFXFwccXFx2NnZsWTJEu666y78/f0BiIiIYPHixa1ZpXZnhMdQxnqO\nIjX/CJ9dSGZqnzu0jiSEENdlk7e9qqqye/duZs+eDcCZM2eYMGECACaTCaPRSFpaWqP5kpKSCA0N\nBSA0NJS9exsfQrtz507rcjMyMhg5ciSOjo4YDAbGjRtHYmKiLVahXZs/YC7Odt3ZfvYTCioLtY4j\nhBDX1aqRyo9SU1MxmUzWEUNgYCBJSUkEBweTm5tLeno6ubm5jBgxosF8RUVFmM1mAMxmM8XFxQ0e\nr6qqYt++fbz44osADBw4kJiYGEpKSnBwcODLL79k2LBh1udv2rSJ+Ph4hg0bxvPPP4+Li0uz8nt4\nGG921W+pH3N5YGTJ2AeJObCOuIyt/PHuKE13g7X37dXeSK6WkVwt095y/WKpREREUFjY+N1xVFQU\n06ZNA2DHjh3W0QRAWFgYGRkZhIWF0atXL0aPHo1er29xuM8++4zbbrsNV1dXAAICAliyZAmLFi3C\nycmJQYMGWZf74IMPsnTpUhRF4bXXXmPVqlX89a9/bdbrXLpU3uJst5qHh7FBrv4OAxjpMYyjl9KI\n++ZT/OyG4+PeHQd7m7wvuOlc7YXkahnJ1TKSq+nXbsov/kXasGHDDR+vra0lMTGRLVu2/LRQg4EV\nK1ZYvw8PD7eOYn7OZDJRUFCA2WymoKDA+iH7j3bu3ElwcHCDafPnz2f+/PkA/P3vf8fT0xMAd3f3\nBs/5zW9+80ur1qEoisIDA0M5VXyGj0/vovpYGV5GEy8+NrbNi0UIIa6n1ftQ9u/fT79+/fDy8rJO\nq6qqorKyEoCUlBT0ej39+/dvNO+UKVOIj48HID4+nqlTp1ofKy8v59ChQw2mwbVdZgA5OTns2bPH\nOkIqKCiwPmfv3r0MGDCgtavW7rh068Ed5umgq8Wu33FyiyrILqzQOpYQQli1+i3url27Go0mioqK\nWLx4MTqdDk9PT9asWWN9LDo6mvDwcIYPH05kZCRRUVFs3rwZb29vXnvtNevzEhMTmThxIk5OTg2W\n/cwzz1BaWorBYGDlypXWz03+9re/ceLECQB8fHx4+eWXW7tq7dL0fhP4z+lU6JFLz4BsfNw79mHT\nQojORVFVVdU6hNY62r7Swooy1qTGUF1fzfKxT9Pb6NMucmlJcrWM5GoZydX0azdFzqTrgNy7uxAx\nLJw6tY4N6R/InSKFEO2GlEoHNcQ0iLt8J5JXWUB8xi6t4wghBCCl0qHNDbgX7+6efHFxP+lFJ7SO\nI4QQUiodmb3ejoghD2JQ9Gz8/iPKLVe0jiSE6OKkVDo4X2MvQgLuodxyhU0nNiPHXQghtCSl0glM\n6T2ZgT37c7zwO1JyvtY6jhCiC5NS6QR0io5HB/8aJ4MjH5/eTn7lJa0jCSG6KCmVTqKngysPBoZh\nqa9hQ/oHcgtiIYQmpFQ6kdvMIxjvNYas8ovsyuz8twQQQrQ/UiqdzPyBczE5uPHp+c84U5qpdRwh\nRBcjpdLJOBoceGxIOADvffd/qaqt0jiREKIrkVLphAJc/ZnpP4Xi6hI+OpWgdRwhRBcipdJJ3es/\nDb8evTmYd5hv8o9oHUcI0UVIqXRSep2eiCHh2Ovs+ODkVkqqS7WOJIToAqRUOjGzkwf3D5hDVW0V\n73/3IfVqvdaRhBCdnJRKJ/erXrczwn0op0ozSMr6Uus4QohOTkqlk1MUhQWB99PD3sj2s59yoTxH\n60hCiE5MSqULcLbvzsODf02dWsf6tE2cuFhItaVW61hCiE5ISqWLGGoaxCTvIPKrLvHqvg/47/dS\npViEEDYnpdKFjDZOpr7SGYPnBQrUDLILK7SOJIToZKRUuhB/sysuhUGodXrs+6VhcJJSEULYlpRK\nF+Jgb+BPD91NSO+5oKvj/ZMfcLXOonUsIUQnIqXSxTjYG5gVOIG7fSeRV5HPByc+lrtFCiFsxtDa\nBURFRZGZee1quOXl5RiNRhISErBYLKxcuZK0tDQURSE6Oprx48c3mr+0tJRly5aRnZ2Nj48PMTEx\nuLi4UF5ezvLly8nJyaGuro5FixYRFhYGwNatW3nrrbcAePLJJ5k3bx4AaWlpvPDCC1RXV3PnnXcS\nHR2NoiitXcVOKbT/vZy7nMWh/G8JcO3LZJ8JWkcSQnQCrR6pxMTEkJCQQEJCAjNmzGD69OkAxMXF\nAbB9+3bWr1/P6tWrqa9vfEZ3bGwsQUFB7Nmzh6CgIGJjYwHYtGkTAQEBbNu2jY0bN7J69WosFgul\npaW88cYbfPTRR8TFxfHGG29QVlYGwJ/+9Cdefvll9uzZw7lz5/jySznZ73oMOgOLhz1MdzsnNp9K\nIOvyRa0jCSE6AZvt/lJVld27dzN79mwAzpw5w4QJ1979mkwmjEYjaWlpjeZLSkoiNDQUgNDQUPbu\n3QtcO2mvoqICVVWpqKjAxcUFg8FAcnIyEydOxNXVFRcXFyZOnMi+ffsoKCjgypUrjB49GkVRCA0N\nJSkpyVar1yn1dHAlYsiD1Kn1rEvbSGVNpdaRhBAdXKt3f/0oNTUVk8mEv78/AIGBgSQlJREcHExu\nbi7p6enk5uYyYsSIBvMVFRVhNpsBMJvNFBcXA7BgwQKefPJJJk+eTEVFBa+++io6nY78/Hy8vLys\n83t6epKfn99oupeXF/n5+c3K7uFhbM2q3zJtketOj7Hk1+ayOX0XH2R8zB8m/QadcuP3Gl15e90M\nydUykqtl2luuZpVKREQEhYWFjaZHRUUxbdo0AHbs2GEdpQCEhYWRkZFBWFgYvXr1YvTo0ej1+mYH\nS05OZvDgwbz//vtkZWWxcOFCxo4d2+SHyoqiXHd6c1y6VN7sXG3Fw8PYZrnuNN9BWs5pDucc54Nv\ndjDD7+52kaslJFfLSK6WkVxNv3ZTmlUqGzZsuOHjtbW1JCYmsmXLlp8WbDCwYsUK6/fh4eHWUczP\nmUwmCgoKMJvNFBQU4ObmBsCWLVuIjIxEURT8/Pzw9fXl7NmzeHl5cfDgQev8+fn53H777Xh5eZGX\nl2ednpeXZx0BiRvTKToihj7IqkOvsS3jE/x79GFgzwCtYwkhOiCbfKayf/9++vXr12D3U1VVFZWV\n1/bRp6SkoNfr6d+/f6N5p0yZQnx8PADx8fFMnToVAG9vbw4cOABAYWEhmZmZ+Pr6MmnSJJKTkykr\nK6OsrIzk5GQmTZqE2Wyme/fuHDlyBFVVGyxL/DKjvTOLhi5AURTeTd9E2dXLWkcSQnRANvlMZdeu\nXQQHBzeYVlRUxOLFi9HpdHh6erJmzRrrY9HR0YSHhzN8+HAiIyOJiopi8+bNeHt789prrwGwdOlS\nXnjhBUJCQlBVleeee846ilm6dCn3338/AE899RSurq7AtaO/fjyk+I477uCOO+6wxep1GQGu/swL\nuJePz+xgffq/eWbU4+h1zd9lKYQQiipnvsm+0p9RVZV1aRs5cimNGX53MzdgVrvI9UskV8tIrpaR\nXE2/dlPkjHrRgKIoPDx4Ph6OJvac/4zjhd9pHUkI0YFIqYhGHA2OLBn2CHY6A+999yGFVcVaRxJC\ndBBSKqJJvsZePDBwHlW1VaxL20hNXY3WkYQQHYCUiriuoF7jCPIex4XybDaf2a51HCFEByClIm7o\n1wND8XH2Jjn7Kw7mHdY6jhCinZNSETdkr7djybCHcdA78MGJj/ny++/lNsRCiOuSUhG/yOzkwQMD\n7sNSX8M/vl7HSxv3S7EIIZokpSKaxURfanL7onOspMTtABfa4TH7QgjtSamIZvFx74575SjqSjzQ\nuxRx6PJnWkcSQrRDUiqiWRzsDfzxsXGsnPEkXk6epOR+xZcX92sdSwjRzkipiGZzsDcwop83S0cu\nxNmuO3Gnt3Gi+LTWsYQQ7YiUimgxk6MbkcMfQ4fCurR/kV9RoHUkIUQ7IaUibkqAqz8PBd5PVW0V\nbx/bQIXcilgIgZSKaIXx3mOY4Xc3BVWFrEv7F3X1dVpHEkJoTEpFtEpIv5mMdB/KqZIzfHQqvsnb\nOgshug4pFdEqOkXHo0PCr13KJedrvpAjwoTo0qRURKs5GLrxmxERGO2d2Xx6G+lFJ7WOJITQiJSK\nsAk3h548Mfwx9Do976ZtIq8iX+tIQggNSKkIm+nr4sfDgfOprqvmraPruVJToXUkIUQbk1IRNjXO\nazT3+E+lsLqYdcc3UlsvF54UoiuRUhE2F9x3OqM8hnO69CwfntwqR4QJ0YVIqQibu3ZE2AP0Nvqw\nP/cQ/7mwT+tIQog2YmjtAqKiosjMzASgvLwco9FIQkICFouFlStXkpaWhqIoREdHM378+Ebzl5aW\nsmzZMrKzs/Hx8SEmJgYXFxfKy8tZvnw5OTk51NXVsWjRIsLCwgDYunUrb731FgBPPvkk8+bNA+CR\nRx6hoKAABwcHAN59911MJlNrV1HchG56e54Y/hh/S32drWd2YnZyZ7j7EK1jCSFusVaXSkxMjPXr\nVatW4ezsDEBcXBwA27dvp6ioiMcff5zNmzej0zUcHMXGxhIUFERkZCSxsbHExsayfPlyNm3aREBA\nAG+//TbFxcXcc889hISEUFlZyRtvvMHHH3+Moijcd999TJkyBRcXFwBeeeUVhg8f3trVEjbQ08GV\nJ0ZE8Orht1if/m8e6PMYI3364mDf6h87IUQ7ZbPdX6qqsnv3bmbPng3AmTNnmDBhAgAmkwmj0Uha\nWlqj+ZKSkggNDQUgNDSUvXv3AqAoChUVFaiqSkVFBS4uLhgMBpKTk5k4cSKurq64uLgwceJE9u2T\n3SvtlV+P3oQPuJ+rdRY2nNjIS//aJ3eNFKITs1mppKamYjKZ8Pf3ByAwMJCkpCRqa2u5cOEC6enp\n5ObmNpqvqKgIs9kMgNlspri4GIAFCxaQkZHB5MmTmTNnDtHR0eh0OvLz8/Hy8rLO7+npSX7+T+dE\nrFixgrlz5/Lmm2/KB8TthIcSQM3F/ui6VVNqTiYjv0jrSEKIW6RZ+yEiIiIoLCxsND0qKopp06YB\nsGPHDusoBSAsLIyMjAzCwsLo1asXo0ePRq/XNztYcnIygwcP5v333ycrK4uFCxcyduzYJotCURTg\n2q4vT09Prly5wm9/+1sSEhKso6Ab8fAwNjtXW+osuZx7OOL5yUgK8i0YPLPYW7yVoBG/o5vBXtNc\nbUVytYzkapn2lqtZpbJhw4YbPl5bW0tiYiJbtmz5acEGAytWrLB+Hx4ebh3F/JzJZKKgoACz2UxB\nQQFubm4AbNmyhcjISBRFwc/PD19fX86ePYuXlxcHDx60zp+fn8/tt98OXBu1ADg7OzN79myOHTvW\nrFK51A7vt+7hYexUuaIfHsOFSwP5vGgHRwqPs/rzt4j84Qx8LXPdapKrZSRXy2iZ63plZpPdX/v3\n76dfv34NdktVVVVRWXntHhspKSno9Xr69+/faN4pU6YQHx8PQHx8PFOnTgXA29ubAwcOAFBYWEhm\nZia+vr5MmjSJ5ORkysrKKCsrIzk5mUmTJlFbW2vddVZTU8Pnn3/OgAEDbLF6wgYc7A0M8OnJwmEP\nMthtIGlFJ9j4fRz1ar3W0YQQNmSTw3B27dpFcHBwg2lFRUUsXrwYnU6Hp6cna9assT4WHR1NeHg4\nw4cPJzIykqioKDZv3oy3tzevvfYaAEuXLuWFF14gJCQEVVV57rnnrKOYpUuXcv/99wPw1FNP4erq\nSmVlJUuWLKGmpob6+nqCgoL49a9/bYvVEzZk0Bl4fPij/OPbWA7lH8bZzomwASHWXZhCiI5NUeXT\nbBnWtoCtcl2pqeDVw2+TV5FPSL+Z3OM/tV3ksjXJ1TKSq2U67e4vIVrK2a47z4xagptDT7af/ZR9\n2Qe0jiSEsAEpFaEZ124uPD1qCc523fnwZDyHC45pHUkI0UpSKkJTnk4ePDVqMd309mxI/4Dvi09p\nHUkI0QpSKkJzfYy+PDEiAkVRiD3+PpllWVpHEkLcJCkV0S4M7BnAoqEPUVNXw1tH35U7RwrRQUmp\niHZjpMcwHgq8n4raSl4/so6iqhKtIwkhWkhKRbQrv+o1jtCAeym9WsYbR9+h3HJF60hCiBaQUhHt\nznS/u5je5y4KKgv559H/obq2WutIQohmklIR7dLcgFn8ynscWeXZvHV0AycvFskl84XoAKRURLuk\nKArhg+5jmNsQzpSd5dWvNvDyewelWIRo56RURLul1+mZ4h5C3WU39G75FLl+xYV2eKkMIcRPpFRE\nu+ZndsGtcCJ15a4YTHn8p3AbdfV1WscSQlyHlIpo1xzsDfzx0SB+N+ZxAnr05VhROu+kbaSmXnaD\nCdEeSamIds/B3sBgXw+eHr2YwJ4DOF74HbHH36OmrkbraEKI/0VKRXQY9np7nhgRwRC3QXxXdJK3\nj23AUmfROpYQ4mekVESHYq+3I3LEYwx3H8yJktP88+i7VNde1TqWEOIHUiqiw7HTGVgy7BFGeQzj\ndOlZ3jz6P1TWVGkdSwiBlIrooAw6A4uGLmCMeSRny87x58//IcUiRDsgpSI6LL1Oz2NDwrnd6zZO\nF5/j9SOxVNRUah1LiC5NSkV0aHqdnkcG/5q7+/6KrPJsXvt2LVcsFVrHEqLLklIRHZ5O0fHEuAVM\n8plA9pVcYr59m8sWOfNeCC1IqYhOQafoCB84j7t8J5JbkU/M4bWUXi3TOpYQXY6Uiug0FEXh/gFz\nmNr7DvIrC4g5/DYl1aVaxxKiSzG0dgFRUVFkZmYCUF5ejtFoJCEhAYvFwsqVK0lLS0NRFKKjoxk/\nfnyj+UtLS1m2bBnZ2dn4+PgQExODi4sL5eXlLF++nJycHOrq6li0aBFhYWEALF68mKNHjzJmzBjW\nrl1rXdaFCxd49tlnKSsrY8iQIaxZswZ7e/vWrqLoQBRFYV7/YAw6A5+e/w+vHn6b3wxbTNUVe3zc\nu+Ng3+ofeSHEDbR6pBITE0NCQgIJCQnMmDGD6dOnAxAXFwfA9u3bWb9+PatXr6a+vr7R/LGxsQQF\nBbFnzx6CgoKIjY0FYNOmTQQEBLBt2zY2btzI6tWrsViunT29ZMkS1qxZ02hZr7zyChEREezZs4ce\nPXqwefPm1q6e6IAURSGk30zu7Tudoupi/nLgDf7y4Zf893upcul8IW4xm+3+UlWV3bt3M3v2bADO\nnDnDhAkTADCZTBiNRtLS0hrNl5SURGhoKAChoaHs3bsXuPaHoaKiAlVVqaiowMXFBYPh2rvMoKAg\nunfv3uj1v/rqK2bOnAnAvHnzSEpKstXqiQ5GURSC+05novtdqHZVdBvyFXnVOWQXypFhQtxKNtsX\nkJqaislkwt/fH4DAwECSkpIIDg4mNzeX9PR0cnNzGTFiRIP5ioqKMJvNAJjNZoqLiwFYsGABTz75\nJJMnT6aiooJXX30Vne76HVhSUkKPHj2sxePl5UV+fn6zsnt4GFu6um1CcrVMU7kiJ4Vx5H/KuOL2\nLQ6DD2IxDsXDw1fzXO2B5GoZydU8zSqViIgICgsLG02Piopi2rRpAOzYscM6SgEICwsjIyODsLAw\nevXqxejRo9Hr9c0OlpyczODBg3n//ffJyspi4cKFjB07Fmdn52YvQ1GUZj3vUju88ZOHh1FytcCN\ncr08dz7J5wayK3crbx56l+ySPKb2vqPZPx+3KpeWJFfLSK6mX7spzSqVDRs23PDx2tpaEhMT2bJl\ny08LNhhYsWKF9fvw8HDrKObnTCYTBQUFmM1mCgoKcHNzA2DLli1ERkaiKAp+fn74+vpy9uzZRiOd\nH/Xs2ZPLly9TW1uLwWAgLy/POgISXZuDvYFpA8cwyNubt46+y9YzOymsKmb+gDnodc1/oyOE+GU2\n+Uxl//799OvXDy8vL+u0qqpm0mWgAAAawElEQVQqKiuvXTIjJSUFvV5P//79G807ZcoU4uPjAYiP\nj2fq1KkAeHt7c+DAAQAKCwvJzMzE1/f6uy0URWH8+PF8+umnAGzdupUpU6bYYvVEJ9Hb2IvlY5/G\nx9mbfdkHWHv8PbnCsRA2ZpNS2bVrF8HBwQ2mFRUVMW/ePGbNmsU777zT4Git6Ohojh8/DkBkZCQp\nKSnMmDGDlJQUIiMjAVi6dCnffvstISEhRERE8Nxzz1lHMQ899BC/+93vOHDgAHfccQf79u0DYPny\n5axfv57p06dTWlrK/PnzbbF6ohPp6eDKstueZLDbQNKLTvDq4bfkJEkhbEhRVVXVOoTWZF9p83WW\nXHX1dXx4Kp6UnK9x7ebC0pGL8HH21jxXW5FcLSO5mn7tpsgZ9aJL0uv0PDjoPkID7qX0ahl//+af\nfFd0UutYQnR4Uiqiy1IUhel+d7Fo6AJq1TreOraelOyvtY4lRIcmpSK6vDGeI/nd6EgcDQ78++TH\nJGTspl5tfPUHIcQvk1IRAujn4s9zY57G7OjOnvOfsSH9A2rqarSOJUSHI6UixA/MTu78fuxTBLj4\n803BUf5x5B254ZcQLSSlIsTPONt155lRjzPGPJKzZef4W+obpJ7LlAtRCtFMUipC/C92ejsihj7I\nVN+7KKwu4t1T7/Di5gQpFiGaQUpFiCboFB0jnSdiyRgOSj2VXl+zKT2e2nopFiFuREpFiOvwce+O\nmQFc/S4IncXI4ZKDvHr4bYqqSrSOJkS7JbfBE+I6HOwNvPjYWLILK3DvOY2tZ7dzKP8wqw7F8OiQ\nBxjuPkTriEK0OzJSEeIGHOwNBPRywcWxO48NeYCHAsOw1Nfw9rENbD2zk7r6Oq0jCtGuSKkI0UyK\nojCx13iW/3A+y96sL4j5di0l1aVaRxOi3ZBSEaKFfI29+MO431oPO1516DXS5bphQgBSKkLcFEeD\nAwuHPsQDA0Oprq3mn0f/h+0Zn8juMNHlSakIcZMUReEO31/x+zFP4e7gxifn/8PrR96h7OplraMJ\noRkpFSFaqU8PX/5r3O8Y6TGM06Vn+evBGE4Wn9E6lhCakFIRwgac7Bx5fNgj3D9gDpW1Vbx+5B22\nnfmU788Vypn4okuR81SEsBFFUbi79yT8e/Thf9L+xadZSew6/i2upeP404I7cbCXXzfR+clIRQgb\n6+vSh/A+i6grMaN3Keay7162n/pM7tEiugQpFSFugf6e7rgVT8SSMQIdej4vSOT/fPNPcq7kaR1N\niFtKxuNC3AIO9gb++Ng4KmvHUldfwY7zu0jNP8KqQ68x038KM/3uxqCTXz/R+chIRYhbxMHewCA/\nNzycXVk49CF+MyICo70zuzITWXXoNTLLzmsdUQibk1IRoo0Mdx/C/zf+90z2CSK3Ip//880/2Xxq\nG9W1V7WOJoTNtGr8HRUVRWZmJgDl5eUYjUYSEhKwWCysXLmStLQ0FEUhOjqa8ePHN5q/tLSUZcuW\nkZ2djY+PDzExMbi4uFBeXs7y5cvJycmhrq6ORYsWERYWBsDixYs5evQoY8aMYe3atdZlPf/88xw8\neBCj0QjAqlWrGDx4cGtWTwibczQ4ED5oHmM9R7HpRByfXUzmaGE6Dw0KY7BpoNbxhGi1VpVKTEyM\n9etVq1bh7OwMQFxcHADbt2+nqKiIxx9/nM2bN6PTNRwYxcbGEhQURGRkJLGxscTGxrJ8+XI2bdpE\nQEAAb7/9NsXFxdxzzz2EhIRgb2/PkiVLqKqq4sMPP2yU5w9/+AP33HNPa1ZJiDbR37UvK8YtY/e5\nJBKzPueNo+sY7zWG+wbMxtmuu9bxhLhpNtn9paoqu3fvZvbs2QCcOXOGCRMmAGAymTAajaSlpTWa\nLykpidDQUABCQ0PZu3cvcO14/4qKClRVpaKiAhcXFwyGa/0XFBRE9+7ySyc6Pju9HXMC7uEPY39L\nb6MPX+d9w///1f/hm/yjqKqqdTwhbopNDj9JTU3FZDLh7+8PQGBgIElJSQQHB5Obm0t6ejq5ubmM\nGDGiwXxFRUWYzWYAzGYzxcXFACxYsIAnn3ySyZMnU1FRwauvvtpolNOUV199lTfffJOgoCCee+45\n7O3tm5Xfw8PYgrVtO5KrZTpqLg+PQYz0f4Gdp5L4MG0H76Zv4tuiY0zrNYthfXrj2O3WHCXWUbeX\nViRX8/ziT2tERASFhYWNpkdFRTFt2jQAduzYYR2lAISFhZGRkUFYWBi9evVi9OjR6PX6ZodKTk5m\n8ODBvP/++2RlZbFw4ULGjh1r3b3WlGeffRYPDw9qamp48cUXiY2N5emnn27W6126VN7sbG3Fw8Mo\nuVqgM+QKMgURMG4Am77fzLd5xzmc/R2OiYP44+xf4+LopFmutiS5WkbLXNcrs18slQ0bNtzw8dra\nWhITE9myZctPCzUYWLFihfX78PBw6yjm50wmEwUFBZjNZgoKCnBzcwNgy5YtREZGoigKfn5++Pr6\ncvbs2UYjnZ/7ccRjb2/Pfffdx7vvvvtLqyZEu2N2cifEK5zVRxKw8z1Ftek7/nzwb8wOmMHEXrej\n1zX/zZkQWmj1Zyr79++nX79+eHl5WadVVVVRWVkJQEpKCnq9nv79+zead8qUKcTHxwMQHx/P1KlT\nAfD29ubAgQMAFBYWkpmZia+v7w1zFBQUANc+39m7dy8DBgxo7aoJoQlfD2fM9YOoPnon3YoDqVFr\n+PDUVv7761f4Jv+IXO5FtGuK2spPBJ9//nlGjhzJgw8+aJ128eJFFi9ejE6nw9PTkz//+c/4+PgA\nEB0dTXh4OMOHD6ekpISoqChyc3Px9vbmtddew9XVlfz8fF544QUuXbqEqqo8/vjjzJ07F4CHHnqI\ns2fPUllZiaurK3/+85+ZPHkyjz76KCUlJaiqSmBgIC+99FKzP9CXYW3zSa6Wudlc1ZZasgsr8HHv\njoUqPjmXRHL219SpdfQ2+jA3YBaD3W7+EOTOtr1uNcnV9Gs3pdWl0hnID0vzSa6WsWWuwqoitp/9\nlNT8IwAM6tmfuQGz8OvRW9NctiS5WqY9loqcUS9EB+HuaGLh0Id4flwUQ9wGcbLkDGtSX2dd2r/I\nr7ykdTzRwVRbasnIKbP5/X7kinZCdDC9jb14atRiTpVkEJ+xi28LjnH0UhpB3uO4t+80XLu5aB1R\ntGNZ5Rf5NPNzjhR8x9UTY/Ds5sOLj4212f1+pFSE6KAG9gxg+ZinOXopjW1nPyEl52sO5h3m7t6T\nuMN7EsWl9fi4d5ebgwlUVeW74lPszfqCUyXXbnVdX2VEtTiQe6WS7MIKAnrZ5s2I/LQJ0YEpisIo\n83CGuw/hq7xUdmXuZc/5z0g8m4wlvzcmy0BWPnyHFEsXVVtfyzf5R9mb9QU5Fdfu5RPYcwB39JrE\nh9tKybNU4W1ywsfddlcpkZ80IToBvU7PxF7jGed5G1u+S+LL3H3Y9TpLmZrJ20fPEdz/Lvq79kVR\nFK2jijZQVVtFcvbXfH4xhdKrZegUHWM9RzGtz530Nl47EnfQYz8dYWjLNx1SKkJ0IvZ6O0IHTePY\n185cUjJw6HWR0+UniPn2BD7O3tzp8yvGeY3WOqa4RUqqS/nsYjIp2QeprqvGXm/P3b0ncbfvZEyO\nPRs818HeYLNdXj8npSJEJ+Ngb+CPj04gu3A4vUxOZFdd5POLKRy9lMa/T35MfMYupgZMZKzbWNwd\n3bSOK2wg+0ouSVlfcij/W+rVenrYG5nhdxeTfSbgZGfbS/z8EikVITqhn78L7d+tL/1d+1J6tYx9\n2V+Rkv0120/uZQdJDHMfzJ2+vyKw5wDZNdbBVF2tYfexQxzIS+ZEySkAvJzMTO1zJ+O8RmOn0e2q\npVSE6CJcu7kQ0m8m9/hP5UzVKbZ/n8Txwu84Xvgdnk5m7vT9FeO9bsPB4KB1VHEDeRX5fJVzmKSM\nQ9TbXwGgXw9/ZvjfxVBTIDpF29MPpVSE6GLsdAbu8B/P4O5DOHc5iy8u7udw/lE+OhXPtozdjDXf\nhn+3IYzy6YdjNzut4wqgqKqYb/KPklpwhOwruQCoeh11Rd7U5vkRGjaVAPf2cX6SlIoQXZh/jz74\nD+nDvP7BpGQf5MvsAyTnHiCZA/z7tBOT/EZzm+cwAlz7av4OuKu5bCnncP4xUvOPkHn5PAB6Rc9w\n98GMMI1gx+4q8gotNj8kuLWkVIQQ9LA3MqvvVALsR7Nmxyfoe+ajd73ElzkpfJmTgrNdd4a5D2aU\nxzAG9RyAvV5GMLdCZU0lRy6lkZp/hFMlGaioKCgM6tmfMZ4jGeUxnO4/fPB+26O1VNaqOBmUdnUe\nUvtJIoTQXB+PHnjq+pF71guTyYFfz3Hl+9ITHL+Uzle5qXyVm4q93p4hboMY6TGUYabANj+6qDOp\nttRyrqCEEiWLo0XH+a7oJHVqHQB9e/RhjOcobjOPxKVb44s3Otgb6O3T/i50KaUihLBysDfw4mNj\nG5wUN8pzCA8MDOX85QscvZTO0UtpHLl0nCOXjqNTdAx0DWCkx1BGeAzFQel+S06o60xq62u5UJ7D\niaIMPkk/Qo1DAYr+WpH4OHsz1jyK2zxHdtjDveX/uhCigaZOitMpOvq6+NHXxY+5AbPIryzgyKV0\njl1K50TJaU6UnObDU/Hoq3tSXeSGq87Mc3Pvwuzc8zqv0nVU11aTeTmLjNJMMkrPkXk5i5r6mmsP\ndge12onaPG+WTJrK7X0b38ywo5FSEUK0iKIoeHX35J7untzjP4WS6lKOFX7HVxePcF49j51PCRVk\n8NLBA7h2c8HP6EufHr74GXvTu4cPznbt50PlW+GypZyM0nPXSqQsk4tXcq1361RQ6OXsRYCLP32c\n+7Dt0zLyC8Db5MQIH39tg9uIlIoQolV6OrheO8fFfDsvbdzPJUsuLh6V9OuvcvFKNkcL0zlamG59\nvsnBDb8evvQx+uLXw5feRh8cDY5UW2o5eb643X3wfCNX6yzkXC7gWO5ZStVczl0+T0FVofVxg6Kn\nb48+BLj2JcDFn34ufg0+gxr98K25/paWOsdaCCE052BvYOUjv2r0R7L0ahnnL18kq/wiWZcvcr78\nAocLjnG44Jh1Xg9Hd0oLHKksccSlWw8emToCdydXenQz0t3gpNnZ/pa6GoqrS7hYe56zeTkUV5dQ\nVF1MUdW1f6/UVDR4voO+G0NMg+jv0pcA1774GX2xu8GRcrfq+ltaklIRQthMU38kXbu54OrhwkiP\nocC1e3sUV5dw3loyFzlfdoEaYyF2RqgE1qalWufXK3qM9s70sDf+9F+3a/+6/PB1N8WJsrJru5Hs\n7BTq1Xrq1Xrq6uuo++HrerX+h69/Pu3a11UWC+eLLlFvV0mZpZSiH8qj3HKlyfU0KHrcHHpisjOT\nca6G+koj9eU9ibr/Tgb4dO3PkaRUhBBtSlEUTI5umBzduM08AoDKqxZe/uBLCqsv4eoKd4x1o6Ku\ngvKr5Vy2XPsvpyKPrPKLN174adtk1Ct6ejq40qunFyYHN/q4e9GtzgmTgxsmx570sDeiU3RUW2r5\n7+Op5BZV4m1yovd17tvelUipCCE059TNnj89dNcNT+ZTVZXqumou/1A0ZT+UTVZRIQdOnkexqwFV\nYVDvnvRw6oZO0aFX9D/8q0On6H/4V/ezaTrKrtTw+be5qJZuqFcdeTpkPCP6+DS4goCHR9PngzR1\nCHZXJ1tACNEu/NLJfIqi4GhwxNHgiGd3s3V6tWctpw/9NFp4MqRl91uvttSS/vVP8wd6e7fokjSd\n8XOR1mh1qURFRZGZmQlAeXk5RqORhIQELBYLK1euJC0tDUVRiI6OZvz48Y3mLy0tZdmyZWRnZ+Pj\n40NMTAwuLi6Ul5ezfPlycnJyqKurY9GiRYSFhfH999/zpz/9iStXrqDT6XjyySe59957Abhw4QLP\nPvssZWVlDBkyhDVr1mBvb9/aVRRCtGOtHS3IaMO2Wn2FuJiYGBISEkhISGDGjBlMnz4dgLi4OAC2\nb9/O+vXrWb16NfX19Y3mj42NJSgoiD179hAUFERsbCwAmzZtIiAggG3btrFx40ZWr16NxWLBwcGB\n1atXs3PnTtatW8df/vIXLl++DMArr7xCREQEe/bsoUePHmzevLm1qyeE6AB+HC3cbCG0dn7xE5td\ndlRVVXbv3s3s2bMBOHPmDBMmTADAZDJhNBpJS0trNF9SUhKhoaEAhIaGsnfvXuDaULeiogJVVamo\nqMDFxQWDwUDfvn3x9/cHwNPTEzc3N4qLi1FVla+++oqZM2cCMG/ePJKSkmy1ekIIIZrBZqWSmpqK\nyWSy/sEPDAwkKSmJ2tpaLly4QHp6Orm5uY3mKyoqwmy+tn/UbDZTXFwMwIIFC8jIyGDy5MnMmTOH\n6OhodLqGcY8dO0ZNTQ19+vShpKSEHj16YDBce6fh5eVFfn6+rVZPCCFEMzRrrBcREUFhYWGj6VFR\nUUybNg2AHTt2WEcpAGFhYWRkZBAWFkavXr0YPXo0er2+2cGSk5MZPHgw77//PllZWSxcuJCxY8fi\n7OwMQEFBAcuXL2f16tWNyuZHzT1hyqOdHgYouVpGcrWM5GoZydU8zSqVDRs23PDx2tpaEhMT2bJl\ny08LNhhYsWKF9fvw8HDrKObnTCYTBQUFmM1mCgoKcHO7dmXOLVu2EBkZiaIo+Pn54evry9mzZxkx\nYgRXrlzhiSeeICoqilGjRgHQs2dPLl++TG1tLQaDgby8POsI6Je0t0tHw/UPYdSa5GoZydUykqtl\ntMx1vTKzye6v/fv3069fP7y8vKzTqqqqqKysBCAlJQW9Xk///o2vwDllyhTi4+MBiI+PZ+rUqQB4\ne3tz4MABAAoLC8nMzMTX1xeLxcJTTz3F3LlzmTVrlnU5iqIwfvx4Pv30UwC2bt3KlClTbLF6Qggh\nmskmpbJr1y6Cg4MbTCsqKmLevHnMmjWLd955hzVr1lgfi46O5vjx4wBERkaSkpLCjBkzSElJITIy\nEoClS5fy7bffEhISQkREBM899xxubm7s3r2b1NRUtm7dyty5c5k7dy7ff/89AMuXL2f9+vVMnz6d\n0tJS5s+fb4vVE0II0UyKqqqq1iGEEEJ0DjY7+ksIIYSQUhFCCGEzUipCCCFsRkpFCCGEzUipCCGE\nsBkpFSGEEDYjpSKEEMJmOlWpvPDCCwQFBTW4BllpaSkLFy5kxowZLFy4kLKyMgDKysp46qmnCAkJ\n4f777+fUqVNNLvPChQvMnz+fGTNmEBUVhcViaRe5nn/+eaZMmdLoBNDW5tq9ezfBwcEEBgZaT1D9\n0dq1a5k+fTozZ85k3759TS7zVm2v1uZq6+1VUlLCI488wujRo3n55Zevu8zr/Rxonev1119n8uTJ\n1u31xRdf3NJcKSkp3HfffYSEhHDfffdZr6bxv7X19mpurrbeXseOHbO+1pw5c0hMTGxymbb4fWwx\ntRM5ePCgmpaWpgYHB1unrV69Wl27dq2qqqq6du1adc2aNaqqquqqVavU119/XVVVVT1z5oz66KOP\nNrnM3/72t+qOHTtUVVXVF198Ud20aVO7yPVf//Vf6u7du1uc5ZdynTlzRs3IyFAffvhh9dixY9bp\np0+fVkNCQtSrV6+qWVlZ6tSpU9Xa2tpGy7xV26u1udp6e1VUVKiHDh1S//3vf6svvfTSdZd5vZ8D\nrXP94x//UNetW9fiLDebKz09Xc3Ly1NVVVVPnjypTpo0qclltvX2am6utt5elZWVak1Njaqqqpqf\nn69OmDDB+v3P2eL3saU61Uhl3LhxuLg0vK3n9e7XkpGRYb3fS0BAANnZ2Y2uxKza6B4tts5lK03l\nCggIoF+/fo2em5SURHBwMPb29vTu3Rs/Pz+OHTvW4Dm3cnu1JpettCSXk5MTY8eOpVu3bjdc5vV+\nDrTOZQstyTVkyBA8PT0BGDBgABaLpcl31W29vZqbyxZaksvR0dF6m4+rV682eUV2W/0+tlSnKpWm\nXO9+LYGBgdYh47Fjx8jJySEvL6/BvLfyHi2tyfWjV199lZCQEP7yl7/c8mFtfn5+gwuGenp6NtoW\nWtzTpjm5ftSW26u5rvdz0B5s2rSJkJAQXnjhhZvazXSzPv30UwYPHtzkrcC13F43ygVtv72OHj1K\ncHAwc+bM4aWXXrL+3v1Iq3tMdfpSuZ7IyEguX77M3Llz2bhxI4MHD270P6Upzb1Hy63O9eyzz/LJ\nJ5/w8ccfU1ZWZr0N862iNnGJuOZsi1u9vZqbq623V0f34IMPkpiYSEJCAmazmVWrVrXJ654+fZpX\nXnnlhp/3aOGXcmmxvUaOHMnOnTvZvHkza9eu5erVq784z63+fYQuUCo/3q8FaHC/FmdnZ/7617+S\nkJDAmjVrKCkpwdfXt8G8P79HC9Cie7Tcylxw7V2aoijY29tz3333Nfrw2ta8vLwajJjy8/MbbYtb\nub1akwvafns11/V+DrTm7u6OXq9Hp9Mxf/78NtleeXl5PP3006xevZo+ffo0+RwttldzcmmxvX4U\nEBCAo6Njo4N6tPh9hC5QKte7X8vly5etu0Di4uIa3FXyR7fyHi2tyQVYf7FUVWXv3r0MGDDAJrlu\nlHfnzp1YLBYuXLjAuXPnGDFiRIPnaHFPm+bkgrbfXs11vZ8Drf24vYA22V6XL18mMjKSZ599ljFj\nxlz3eW29vZqbq62314ULF6xlkZ2dTWZmJj4+Pg2eo9k9pm75oQBtaNmyZerEiRPVIUOGqJMnT1Y/\n+ugjtbi4WH300UfV6dOnq48++qhaUlKiqqqqHj58WJ0+fbo6c+ZM9amnnlJLS0uty1myZIn1iI+s\nrCw1LCxMnTZtmvrMM8+oV69ebRe5HnnkEXX27NlqcHCw+vvf/169cuWKTXLt2bNHnTx5sjp06FA1\nKChIXbRokfX5//znP9WpU6eqM2bMUD///PM23V6tzaXF9rr77rvVcePGqaNGjVInT56snj59WlVV\nVV2xYoX1SJ7r/Rxoneu5555TZ8+erc6ePVt94okn1Pz8/Fua680331RHjhypzpkzx/pfYWGh5tur\nubnaentt3bpVvffee9U5c+aooaGhamJionU5tv59bCm5n4oQQgib6fS7v4QQQrQdKRUhhBA2I6Ui\nhBDCZqRUhBBC2IyUihBCCJuRUhFCCGEzUipCCCFs5v8BfgU/kvkHNGIAAAAASUVORK5CYII=\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a452250>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Mean Square Error = 1.09e-12\n"
     ]
    },
    {
     "data": {
      "text/markdown": [
       "Fitted function: $f(x) = -79.082 + 0.00033(x-112.271)^2$"
      ],
      "text/plain": [
       "<IPython.core.display.Markdown object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "coef2 = fit_and_plot(hcc_angles, energy_values2, lambda c, x: c[0]*(x-c[1])**2 + c[2], [1, 112, -79]) \n",
    "display(Markdown(r\"Fitted function: $f(x) = {2:.3f} + {0:.5f}(x-{1:.3f})^2$\".format(*coef2)))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Производя аналогичные предыдущему пункту преобразования, получим, что $K_\\theta = \\dfrac{E}{(\\theta-\\theta_{eq})^2}, $ откуда $K_\\theta = 0.00033 \\dfrac{\\text{Ha}}{\\text{моль}\\cdot \\text{град}^2}$\n",
    "\n",
    "Или же, с учётом того, что в ORCA мы делали расчёт в градусах $(1\\ \\text{град} = 0.01745\\ \\text{рад})$ и единицах Хартри, считает в $K_\\theta = 0.00033 \\cdot 627.509 \\cdot 0.01745^{-2} = 679.79 \\dfrac{\\text{ккал}}{\\text{моль}\\cdot \\text{рад}^2}$"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 185,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "679.7962921751005"
      ]
     },
     "execution_count": 185,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "0.00033  * 627.509 * 0.0174533**-2"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Уравнение для константы взаимодействия из молекулярной механики (формулы 5, 6 в статье):\n",
    "$$\n",
    "K^\\theta_{ijk} = 143.9\\  Z_iC_jZ_k\\left(r_{ij}^{eq}+r_{jk}^{eq}\\right)^{-1}\\cdot\\left(\\theta_{ijk}^{eq}\\right)^{-2}exp\\left\\{\n",
    "{-2}\\cdot\\left(\\frac{r_{ij}^{eq}-r_{jk}^{eq}}{r_{ij}^{eq}+r_{jk}^{eq}}\\right)^2\\right\\} \n",
    ",$$\n",
    "где $i, j, k - $ это атомы С-С-H.\n",
    "Параметры для этого уравнения были взяты из таблицы 4 в статье. "
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 190,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "25.839158719514142"
      ]
     },
     "execution_count": 190,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "r_ij = bl0\n",
    "r_jk = 1.08439\n",
    "Cj = 1.339 \n",
    "Zi = Zk = 1.183\n",
    "grad2rad = 0.0174533\n",
    "143.9 * Zi * Cj * Zk * (r_ij + r_jk)**-1 * (hcc0*grad2rad)**-2 * np.exp(-2 * ((r_ij - r_jk)/(r_ij + r_jk))**2)"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "После подстановки их в уравнение получили значение $K^\\theta_{i\\,j\\,k} = 25.8\\ \\dfrac{\\text{ккал}}{\\text{моль}\\cdot \\text{рад}^2}$\n",
    "\n",
    "В итоге получили значения, отличающиеся на порядок... Если я не допустил нигде ошибки в расчётах, это означает, что квантовые и неквантовые методы действительно могут давать сильно различающиеся результаты. Неквантовые методы хороши для больших молекул, например, сложных белков. Они в этом случае работают быстрее квантовых, и при этом дают приемлемую точность. Здесь же, на малой молекуле, мы видим заметные отличия в результатах."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Часть 3. Зависимость энергии молекулы от торсионного угла связи C−С"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 197,
   "metadata": {},
   "outputs": [],
   "source": [
    "tor_step = 12\n",
    "tor0 = 0\n",
    "params3 = {'blength': 1.52986, 'hcc_angle': 111.200}\n",
    "torsions = np.linspace(tor0 - tor_step*15, tor0 + tor_step*15, 31)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 198,
   "metadata": {},
   "outputs": [],
   "source": [
    "dir3 = './task3/'\n",
    "! mkdir -p {dir3}\n",
    "energy_values3 = []\n",
    "for tor in torsions:\n",
    "    z = gen_zmatrix(tor1 = tor, tor2 = tor-60, tor3 = tor+60, **params3)\n",
    "    ! echo '{z}' > {dir3}{bl}.zm\n",
    "    ! orca {dir3}{bl}.zm > {dir3}{bl}.out 2>{dir3}{bl}.err\n",
    "    res = ! grep 'FINAL SINGLE POINT ENERGY' {dir3}{bl}.out\n",
    "    energy_values3.append(float(res[0].split(' ')[-1]))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 199,
   "metadata": {
    "scrolled": true
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAY8AAAEDCAYAAADN6IhEAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a615390>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plt.plot(torsions, energy_values3, \".\")\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 222,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAY8AAAEDCAYAAADN6IhEAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\njX6IqNRpAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a2243d0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Mean Square Error = 5.71e-12\n"
     ]
    },
    {
     "data": {
      "text/markdown": [
       "Fitted function: $f(x) = -79.081 + \\dfrac{-0.00362}{2} \\cdot (1 + \\cos(0.995x - 0.982))$"
      ],
      "text/plain": [
       "<IPython.core.display.Markdown object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "coef3 = fit_and_plot(torsions, energy_values3, \n",
    "                     lambda c, x: c[0]/2 * (1 + np.cos(c[1]*x - c[2])) + c[3], [1, 1, 1, -79]) \n",
    "display(Markdown(r\"Fitted function: $f(x) = {3:.3f} + \\dfrac{{{0:.5f}}}{{2}} \\cdot (1 + \\cos({1:.3f}x - {2:.3f}))$\"\n",
    "                 .format(*coef3)))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Примечание. Форма моделируемой функции на основе формулы из статьи $E = \\sum\\limits_\\text{dihedrals} \\dfrac{v_n}{2}\\left(1 + \\cos (n \\varphi - \\gamma)\\right) $.\n",
    "\n",
    "Видим на графике **три точки локального минимума**."
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Часть 4. Зависимость энергии молекулы от длины связи C−C с шагом 0.1 Å"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 227,
   "metadata": {},
   "outputs": [],
   "source": [
    "bl_step1 = 0.1\n",
    "bl01 = 1.52986\n",
    "tor = 180\n",
    "params4 = {'hcc_angle': 111.200, 'tor1': tor, 'tor2': tor-60, 'tor3': tor+60}\n",
    "blengths1 = np.linspace(bl01 - bl_step1*10, bl01 + bl_step1*10, 21)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 230,
   "metadata": {},
   "outputs": [],
   "source": [
    "dir4 = './task4/'\n",
    "! mkdir -p {dir4}\n",
    "energy_values4 = []\n",
    "for bl in blengths1:\n",
    "    z = gen_zmatrix(blength = bl, **params4)\n",
    "    ! echo '{z}' > {dir4}{bl}.zm\n",
    "    ! orca {dir4}{bl}.zm > {dir4}{bl}.out 2>{dir4}{bl}.err\n",
    "    res = ! grep 'FINAL SINGLE POINT ENERGY' {dir4}{bl}.out\n",
    "    energy_values4.append(float(res[0].split(' ')[-1]))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 229,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "text/plain": [
       "array([ 0.52986,  0.62986,  0.72986,  0.82986,  0.92986,  1.02986,\n",
       "        1.12986,  1.22986,  1.32986,  1.42986,  1.52986,  1.62986,\n",
       "        1.72986,  1.82986,  1.92986,  2.02986,  2.12986,  2.22986,\n",
       "        2.32986,  2.42986,  2.52986])"
      ]
     },
     "execution_count": 229,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "blengths1"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 231,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXkAAAD4CAYAAAAJmJb0AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz\nAAALEgAACxIB0t1+/AAAADl0RVh0U29mdHdhcmUAbWF0cGxvdGxpYiB2ZXJzaW9uIDIuMS4xLCBo\ndHRwOi8vbWF0cGxvdGxpYi5vcmcvAOZPmwAAF0xJREFUeJzt3XtwVPXBxvEnyRoh2S2JS8IiBGNE\nGkcsyHhrQawQZIYNlwIyvdBJLGKnIMxO3+lFvFDqqDu040Sd2s7YOsHOyLSlsZFc1AhCgVQktELB\n6lgaX7kEyIYAIRfjwnn/4GVrSEj2cHaz4Zfv56/N75yz58nJyZOzv+wlybIsSwAAIyUnOgAAIH4o\neQAwGCUPAAaj5AHAYJQ8ABjMlegAX9TY2BL1upmZaWpubotjmstDLnvIZQ+57BksubKyPJdcdsVe\nybtcKYmO0CNy2UMue8hlD7mu4JIHAPSNkgcAg1HyAGAwSh4ADEbJA4DBKHkAMJgxJd/RGdaBI6fU\n0RlOdBQAGDAG1IuhLldHZ1hPrqtTQ1ObRnrT9HjRbRqSasS3BgCOGHElfzjUqoam868ea2hq0+FQ\na4ITAcDAYETJjxqerpHeNEnSSG+aRg1PT3AiABgYjJjTGJLq0uNFt+lwqFWjhqczVQMA/8+YNhyS\n6tIN1w5LdAwAGFCMmK4BAPSMkgcAg1HyAGAwSh4ADEbJA4DBKHkAMBglDwAGo+QBwGCUPAAYjJIH\nAINR8gBgMEoeAAxGyQOAwSh5ADAYJQ8ABnP0fvKBQED19fWSpJaWFnk8HpWXl0eWHzlyRH6/Xw8/\n/LCWLFniLCkAwDZHJV9SUhK5HQwG5Xa7uyx/5plndPfddzvZBQDAgZh8MpRlWaqurta6desiY2+/\n/bZGjx6ttLS0WOwCAHAZYlLydXV18nq9ys3NlSS1tbXppZde0ssvv6yXX3456vvJzEyTy5US9fpZ\nWR67UfsFuewhlz3ksmew5+qz5IuLixUKhbqNBwIBFRQUSJIqKipUWFgYWfbCCy+oqKhI6enptsI0\nN7dFvW5WlkeNjS227r8/kMsectlDLnsGS67e/mD0WfKlpaW9Lg+Hw6qpqVFZWVlkbM+ePXrzzTf1\ny1/+UqdPn1ZycrKuvvpqLV68OPrUAADHHE/X1NbWKi8vTz6fLzL26quvRm6/8MILSktLo+ABIAEc\nP0++qqpKfr8/FlkAADHm+Eo+GAz2unzFihVOdwEAuEy84hUADEbJA4DBKHkAMBglDwAGo+QBwGCU\nPAAYjJIHAINR8gBgMEoeAAxGyQOAwSh5ADAYJQ8ABqPkAcBglDwAGIySBwCDUfIAYDBKHgAMRskD\ngMEoeQAwGCUPAAaj5AHAYJQ8ABiMkgcAg1HyAGAwSh4ADOZysnEgEFB9fb0kqaWlRR6PR+Xl5Tp0\n6JBmzZql66+/XpI0YcIE/fznP3eeFgBgi6OSLykpidwOBoNyu92Rr8eMGaPy8nIndw8AcCgm0zWW\nZam6ulqFhYWxuDsAQIzEpOTr6urk9XqVm5sbGTt06JDmzZunxYsXq66uLha7AQDYlGRZltXbCsXF\nxQqFQt3GA4GACgoKJEmrV6/Wddddp+9973uSpM7OTrW2tiozM1P79u3T8uXLVVlZ2WU6pyfh8Fm5\nXCmX+70AAC7S55x8aWlpr8vD4bBqampUVlYWGUtNTVVqaqokafz48RozZozq6+t1yy239Hpfzc1t\nUUQ+LyvLo8bGlqjX7y/ksodc9pDLnsGSKyvLc8lljqdramtrlZeXJ5/PFxk7ceKEzp49K0k6ePCg\nPvnkE+Xk5DjdFQDAJkfPrpGkqqoq+f3+LmO7du3S888/r5SUFKWkpGjNmjXKyMhwuisAgE2OSz4Y\nDHYbmzlzpmbOnOn0rgEADvGKVwAwGCUPAAaj5AHAYJQ8ABiMkgcAg1HyAGAwSh4ADEbJA4DBKHkA\nMBglDwAGo+QBwGCUPAAYjJIHAINR8pI6OsM6cOSUOjrDiY4CADHl+K2Gr3QdnWE9ua5ODU1tGulN\n0+NFt2lI6qA/LAAMMeiv5A+HWtXQdP5jBxua2nQ41JrgRAAQO4O+5EcNT9dIb5okaaQ3TaOGpyc4\nEQDEzqCflxiS6tLjRbfpcKhVo4anM1UDwCg0ms4X/Q3XDkt0DACIuUE/XQMAJqPkAcBglDwAGIyS\nBwCDUfIAYDBKHgAMRskDgMEcPU8+EAiovr5ektTS0iKPx6Py8nJJ0ocffqjVq1frzJkzSk5O1oYN\nG3T11Vc7TwwAiJqjki8pKYncDgaDcrvdkqRwOKwf/ehH+sUvfqH8/Hw1NzfL5eJ1VwDQ32IyXWNZ\nlqqrq1VYWChJ2rFjh7785S8rPz9fkpSZmamUlJRY7AoAYENMLq/r6urk9XqVm5srSaqvr1dSUpKW\nLFmiEydOaNasWVq6dGmf95OZmSaXK/o/BllZnsuNHFfksodc9pDLnsGeq8+SLy4uVigU6jYeCARU\nUFAgSaqoqIhcxUvS2bNntXv3bm3YsEFDhw5VcXGxxo8fr69+9au97qu5uS3q4FlZHjU2tkS9fn8h\nlz3ksodc9gyWXL39weiz5EtLS3tdHg6HVVNTo7KyssiYz+fTHXfcoWuuuUaSNHXqVO3fv7/PkgcA\nxJbjOfna2lrl5eXJ5/NFxqZMmaKPPvpI7e3tCofD2rVrl8aOHet0VwAAmxzPyVdVVcnv93cZGzZs\nmIqLi7Vw4UIlJSVp6tSp+vrXv+50VwAAmxyXfDAY7HF87ty5mjt3rtO7BwA4wCteAcBglDwAGIyS\nBwCDUfIAYDBKHgAMRskDgMEoeQAwGCUPAAaj5AHAYJQ8ABiMkgcAg1HyAGAwSh4ADEbJA4DBKHkA\nMBglDwAGo+QBwGCUPAAYjJIHAINR8gBgMEoeAAxGyQOAwSh5ADAYJQ8ABqPkAcBglDwAGMzlZONA\nIKD6+npJUktLizwej8rLy/X666/rd7/7XWS9jz76SK+99ppuuukmZ2kHoI7OsA6HWjVqeLqGpDo6\nnAAQc45aqaSkJHI7GAzK7XZLkubMmaM5c+ZIOl/wy5YtM7bgn1xXp4amNo30punxotsSHQkAuojJ\ndI1lWaqurlZhYWG3ZZWVlT2Om+BwqFUNTW2SpIamNh0OtSY4EQB0FZP5hbq6Onm9XuXm5nZbVlVV\npRdffDGq+8nMTJPLlRL1frOyPFGvGw/uLw3V6Gy3Dh0/o9HZbk3I9w2IXJdCLnvIZQ+57OmvXH2W\nfHFxsUKhULfxQCCggoICSVJFRUWPV+t79uzR0KFDNW7cuKjCNDe3RbWedP4ANTa2RL1+vKxaPCky\nJ3/mdLuGDpBcFxsox+ti5LKHXPYMlly9/cHos+RLS0t7XR4Oh1VTU6OysrJuyyorK+X3+/tOeAUb\nkurSDdcOS3QMAOiR4zn52tpa5eXlyefzdRk/d+6c3njjDeNLHgAGMsclX1VV1WOR79q1Sz6fTzk5\nOU53AQC4TI7/8RoMBnscv/POO/XHP/7R6d0DABzgFa8AYDBKHgAMRskDgMEoeQAwGCUPAAaj5AHA\nYJQ8ABiMkgcAg1HyAGAwSh4ADEbJA4DBKHkAMBglDwAGo+QBwGCUPAAYjJIHAINR8gBgMEoeAAxG\nyQOAwSh5ADAYJQ8ABqPkE6ijM6wDR06pozOc6CgADOVKdIDBqqMzrCfX1amhqU0jvWl6vOg2DUnl\nxwEgtriST5DDoVY1NLVJkhqa2nQ41JrgRABMRMknyKjh6RrpTZMkjfSmadTw9AQnAmAiR/MDgUBA\n9fX1kqSWlhZ5PB6Vl5fr888/12OPPaYPPvhA4XBY8+bN0/e///2YBDbFkFSXHi+6TYdDrRo1PJ2p\nGgBx4ahZSkpKIreDwaDcbrck6Y033lBnZ6c2btyo9vZ2+f1++f1+jR492llawwxJdemGa4clOgYA\ng8VkusayLFVXV6uwsFCSlJSUpPb2doXDYXV0dOiqq66K/AEAAPSfmMwR1NXVyev1Kjc3V5I0c+ZM\nbdq0SVOmTFFHR4ceeeQRZWRk9Hk/mZlpcrlSot5vVpbnciPHFbnsIZc95LJnsOfqs+SLi4sVCoW6\njQcCARUUFEiSKioqIlfxkrR3714lJydr27ZtOn36tL797W/ra1/7mnJycnrdV3NzW9TBs7I8amxs\niXr9/kIue8hlD7nsGSy5evuD0WfJl5aW9ro8HA6rpqZGZWVlkbGKigrdfffduuqqq+T1ejVp0iT9\n85//7LPkAQCx5XhOvra2Vnl5efL5fJGxkSNHaufOnbIsS21tbdqzZ4/y8vKc7goAYJPjkq+qqpLf\n7+8y9p3vfEetra0qLCzUwoULNX/+fOXn5zvdFQDAJsf/eA0Gg93G0tPT9fzzzzu9awCAQ7ziFQAM\nRskDgMEoeQAwGCUPAAaj5AHAYJT8FYpPlQIQDd7f9grEp0oBiBZX8lcgPlUKQLQo+SsQnyoFIFo8\nxr8C8alSAKJFO1yh+FQpANFgugYADEbJA4DBKHkAMBglDwAGo+QBwGCU/CDF2yIAgwNPoRyEeFsE\nYPDgSn4Q4m0RgMGDkh+EeFsEYPDgMfogxNsiAIMHv92DFG+LAAwOTNcAgMEoedjG0y+BKwfTNbCF\np18CsdfRGY7b/8j47YQtPT39krl94PKLOt4XTo7uKRAIqL6+XpLU0tIij8ej8vJydXZ2avXq1dq3\nb5+SkpL06KOP6s4774xJYCTWhadfXjghefolBhInV8ROt73coo73hZOjki8pKYncDgaDcrvdkqQ/\n/elPkqSNGzeqqalJS5cu1YYNG5SczL8ArnROn34Zz4elMEMsr4idbGtn306KOt4XTjH5LbMsS9XV\n1Vq3bp0k6d///rfuuusuSZLX65XH49G+ffv0la98JRa7Q4Jd7tMvnfwSov8l4qo41lfEOaMyL3tb\nO+e4k6KO9+tWYnJvdXV18nq9ys3NlSTl5+dr06ZN8vv9amho0P79+9XQ0NBnyWdmpsnlSol6v1lZ\nHiex44ZcPfvof090+UVqC1uSos/V/llYnx49rTG+L2no1fF/FJDo4yX1/D33x/Fq/yysJ0q26tDx\nMxqd7dazgXv6vI8LuS5n2wt6OkdyRkX3/bq/NFSjs92R/U7I93XJZXdbu8fsuf+519bxvjhXtH+Q\n7OozSXFxsUKhULfxQCCggoICSVJFRYUKCwsjyxYsWKADBw5owYIFuvbaa3XrrbcqJaXv8m5ubos6\neFaWR42NLVGv31/IdWlprqQuVztpriRJiipXLP45Zefq8uLjNVCuanNGZfbL8Tpw5JQOHT8jSTp0\n/Iz2fHi01yvbLx4vu9t+UU/niJ3zdtXiSZFjfeZ0u4baOO8v3vZM1Hv9r2vSropq21j/Pvb2h6zP\nn3ppaWmvy8PhsGpqalRWVvbfO3W5tGrVqsjX3/zmNyNX+Ri8nDwsdfpw2knpJWrbK3X6IZFTF05e\nyW3qq8AdP+atra1VXl6efD5fZKy9vV2WZSktLU07duxQSkqKxo4d63RXMMDl/iI5/eeUk9JL1LaJ\nKlrJWdkmsqjRneOSr6qqkt/v7zLW1NSkJUuWKDk5WSNGjNDatWud7gaDnNPiSFRhJuqqNhb/zOOq\n2AxJlmVZiQ5xgZ05qoEwx9wTctnTn7mutDn5aHINFOSyZ0DNyQOmSNSVKVe1SCRenQQABqPkAcBg\nlDwAGIySBwCDUfIAYDBKHgAMNqCeJw8AiC2u5AHAYJQ8ABiMkgcAg1HyAGAwSh4ADEbJA4DBKHkA\nMNiAfKvhv/71r3rqqad07tw53X///XrooYe6LC8rK9PatWs1YsQISdLixYt1//33S5Jee+01/frX\nv5Yk/eAHP9A3vvGNfsv19NNPa+fOnZKkjo4ONTU1qa6uTpJ00003ady4cZKkkSNH6je/+U1MMj3y\nyCPasmWLvF6vKioqui23LEtPPfWUtm7dqiFDhigYDOrmm2+WFN9j1Veu119/XS+99JIkKT09XT/7\n2c+Un58vSZo2bZrS09OVnJyslJSULh8tGe9cO3fu1LJlyzR69GhJ0owZM/Twww9L6vvnH89cv/3t\nb7Vx40ZJ0tmzZ3XgwAH97W9/U0ZGRlyPV0NDg3784x8rFAopOTlZixYtUlFRUZd1EnGORZMrEedY\nNLn6/RyzBphwOGxNnz7d+vTTT63PPvvMmj17tvXxxx93WefPf/6ztWbNmm7bNjc3W9OmTbOam5ut\nkydPWtOmTbNOnjzZb7m+6JVXXrF++tOfRr6eOHFiTHJc7L333rP27dtn+f3+Hpdv2bLFWrJkiXXu\n3DnrH//4h7Vw4ULLsuJ7rKLJtXv37sj+tmzZEsllWZZ17733Wk1NTTHLYifXu+++az300EPdxu3+\n/GOd64s2bdpkffe73418Hc/jdezYMWvfvn2WZVlWS0uLdd9993X7vhNxjkWTKxHnWDS5+vscG3DT\nNXv37tV1112nnJwcpaamyu/3a9OmTVFtu337dk2ePFkZGRkaNmyYJk+erG3btiUkV2VlpQoLC2Oy\n797cfvvtGjbs0h9IsWnTJs2bN09JSUmaOHGiTp8+rePHj8f1WEWTa9KkSZHlEydO1NGjR2O2bye5\nLsXJeRnrXP11bklSdnZ25Krc7XYrLy9Px44d67JOIs6xaHIl4hyLJtelxOscG3Alf+zYsS4fCj5i\nxIgeD9Jbb72l2bNna+XKlWpoaLC1bTxzSdLhw4d16NAh3XXXXZGxzz77TPPnz9eiRYv09ttvxyRT\nNC7O7fP5dOzYsbgeK7s2bNigqVOndhlbsmSJ5s+frz/84Q/9nuf999/XnDlz9OCDD+rjjz+WFN9z\ny4729nZt27ZN9913X5fx/jhehw4d0r/+9S9NmDChy3iiz7FL5fqiRJxjveXqz3NswM3JWz28lU5S\nUlKXr++9914VFhYqNTVV69ev109+8hO98sorUW0bz1wXVFZWaubMmUpJSYmMvfPOOxoxYoQOHjyo\noqIijRs3TmPGjIlJtt5cKnc8j5Ud7777rjZs2KBXX301MrZ+/XqNGDFCTU1NeuCBB5SXl6fbb7+9\nX/LcfPPN2rx5s9LT07V161YtX75cb7311oA5Xu+8844mTZqkjIyMyFh/HK/W1latXLlSq1atktvt\n7rIskedYb7kuSMQ51luu/j7HBtyVvM/n6/Kw6tixY8rOzu6yTmZmplJTUyVJixYt0v79+6PeNp65\nLqiqqpLf7+8yduGfxDk5Obrjjjv0wQcfxCRXXy7OffToUWVnZ8f1WEXrww8/1GOPPaYXX3xRmZmZ\nkfELx8rr9WrGjBnau3dvv2Vyu91KT0+XJN1zzz0Kh8M6ceLEgDhe0vkLiEudW/E6Xp9//rlWrlyp\n2bNnd3sEISXuHOsrl5SYc6yvXP19jg24kr/lllv0ySef6ODBg+rs7FRlZaWmTZvWZZ3jx49Hbm/e\nvFk33HCDJGnKlCnavn27Tp06pVOnTmn79u2aMmVKv+WSpP/85z86ffq0br311sjYqVOn1NnZKUk6\nceKE/v73v2vs2LExydWXadOm6S9/+Yssy9L7778vj8ej7OzsuB6raBw5ckQrVqzQ2rVrdf3110fG\n29radObMmcjtHTt26MYbb+y3XI2NjZErqr179+rcuXPKzMyM+ucfTy0tLdq1a5emT58eGYv38bIs\nS48++qjy8vL0wAMP9LhOIs6xaHIl4hyLJld/n2MDbrrG5XLpiSee0IMPPqizZ89qwYIFuvHGG/Xc\nc89p/Pjxmj59un7/+99r8+bNSklJ0bBhw/TMM89IkjIyMrRs2TItXLhQkrR8+fIuD2vjnUs6f6U1\na9asLg+zDhw4oNWrV0cewi5dujRmJf/DH/5Q7733npqbmzV16lStWLFC4XBYkvStb31L99xzj7Zu\n3aoZM2Zo6NChevrppyXF91hFk+tXv/qVTp48qTVr1khS5GlsTU1NWr58uaTzTxUsLCzsNpcaz1xv\nvvmm1q9fr5SUFA0ZMkTPPvuskpKSLvnz769cklRTU6PJkycrLS0tsl28j9fu3btVXl6ucePGae7c\nuZGsR44ciWRLxDkWTa5EnGPR5Orvc4z3kwcAgw246RoAQOxQ8gBgMEoeAAxGyQOAwSh5ADAYJQ8A\nBqPkAcBg/wcTpxQ4aBL8uAAAAABJRU5ErkJggg==\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f526a3c9910>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "plt.plot(blengths1, energy_values4, \".\")\n",
    "plt.show()"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Теперь это похоже на экспоненциальную зависимость. Это логично, поскольку приближая атомы, мы в какой-то момент получаем очень сильные взаимодействия. Попробуем смоделировать:"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 262,
   "metadata": {},
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAXkAAAD4CAYAAAAJmJb0AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nEZEIppIXEYlgKnkRkQimkhcRiWD/H3J5D1qQCphFAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "<matplotlib.figure.Figure at 0x7f527fccf7d0>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "Mean Square Error = 0.00431\n"
     ]
    },
    {
     "data": {
      "text/markdown": [
       "Fitted function: $f(x) = -79.045 + 4.30784\\cdot exp\\{{-5.243x+ 3.060}\\}$"
      ],
      "text/plain": [
       "<IPython.core.display.Markdown object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "coef4 = fit_and_plot(blengths1, energy_values4, \n",
    "                     lambda c, x: c[0]*(np.exp(c[1]*x + c[2])) + c[3], [1, -1, 1, -79]) \n",
    "display(Markdown(r\"Fitted function: $f(x) = {3:.3f} + {0:.5f}\\cdot exp\\{{{{{1:.3f}x+ {2:.3f}}}\\}}$\"\n",
    "                 .format(*coef4)))"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Источники\n",
    "\n",
    "1. [*Wanf, Wolf et al.* Development and Testing of a General Amber Force Field (PDF)](http://ambermd.org/antechamber/gaff.pdf)\n",
    "1. [Hartree -- Wikipedia](https://en.wikipedia.org/wiki/Hartree)\n",
    "1. [Z-matrix -- Wikipedia](https://en.wikipedia.org/wiki/Z-matrix_(chemistry%29)"
   ]
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "hse-py27",
   "language": "python",
   "name": "hse"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.14"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 2
}
